yt.utilities.lib.bounded\_priority\_queue module
================================================

.. automodule:: yt.utilities.lib.bounded_priority_queue
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
